use db::permissions::PermissionRaw;

use crate::prelude::*;

#[derive(Deserialize, Debug)]
pub struct Params {
    folder_id: Uuid,
    permission_type: PermissionRaw,
    user_id: i32,
}

pub async fn set(
    claims: Claims,
    State(state): State<AppState>,
    Json(params): Json<Params>,
) -> Result<StatusCode, StatusCode> {
    db::folder::get_permissions(params.folder_id, claims.user_id, &state.pool)
        .await
        .handle_internal()?
        .can_manage_guard()?;

    db::permissions::insert(
        params.user_id,
        params.folder_id,
        params.permission_type,
        &state.pool,
    )
    .await
    .handle_internal()?;

    Ok(StatusCode::NO_CONTENT)
}
